@@ -26,7 +26,8 @@
 #include "parleymainwindow.h"
 #include "version.h"
 
-#include <kaboutdata.h>
+#include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
 
@@ -105,12 +106,13 @@ int main(int argc, char* argv[])
                         ki18n("Conceived the name Parley").toString());
 
     KAboutData::setApplicationData(aboutData);
-
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QApplication::setApplicationName(QStringLiteral("parley"));
     QApplication::setApplicationVersion(PARLEY_VERSION_STRING);
     QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
     QApplication::setApplicationDisplayName(i18n("Parley"));
 
+    KCrash::initialize();
 
     QCommandLineParser parser;
     parser.addVersionOption();
