@@ -63,7 +63,7 @@ void fetchGrammar(KEduVocDocument* doc, int languageIndex)
 {
     QString locale = doc->identifier(languageIndex).locale();
 
-    QUrl location(QUrl::fromUserInput(QStringLiteral("http://edu.kde.org/parley/locale/") + locale + QStringLiteral(".kvtml")) );
+    QUrl location(QUrl::fromUserInput(QStringLiteral("http://edu.kde.org/parley/locale/") + locale.split('_').at(0).toLower() + QStringLiteral(".kvtml")) );
 
     KEduVocDocument grammarDoc;
     if (grammarDoc.open(location) == KEduVocDocument::NoError) {
@@ -333,7 +333,7 @@ void ParleyDocument::openGHNS()
 
 void ParleyDocument::save()
 {
-    if (m_doc->url().fileName() == i18n("Untitled")) {
+    if (m_doc->url().fileName() == QString()) {
         saveAs();
         return;
     }
