@@ -14,7 +14,7 @@
 #ifndef PRACTICE_IMAGEWIDGET_H
 #define PRACTICE_IMAGEWIDGET_H
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class QTimeLine;
 
